(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
    typeof define === 'function' && define.amd ? define(factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, (global.Pdf = global.Pdf || {}, global.Pdf.svelte = factory()));
}(this, (function () { 'use strict';

    function noop() { }
    function assign(tar, src) {
        // @ts-ignore
        for (const k in src)
            tar[k] = src[k];
        return tar;
    }
    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function is_function(thing) {
        return typeof thing === 'function';
    }
    function safe_not_equal(a, b) {
        return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
    }
    function is_empty(obj) {
        return Object.keys(obj).length === 0;
    }
    function create_slot(definition, ctx, $$scope, fn) {
        if (definition) {
            const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
            return definition[0](slot_ctx);
        }
    }
    function get_slot_context(definition, ctx, $$scope, fn) {
        return definition[1] && fn
            ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
            : $$scope.ctx;
    }
    function get_slot_changes(definition, $$scope, dirty, fn) {
        if (definition[2] && fn) {
            const lets = definition[2](fn(dirty));
            if ($$scope.dirty === undefined) {
                return lets;
            }
            if (typeof lets === 'object') {
                const merged = [];
                const len = Math.max($$scope.dirty.length, lets.length);
                for (let i = 0; i < len; i += 1) {
                    merged[i] = $$scope.dirty[i] | lets[i];
                }
                return merged;
            }
            return $$scope.dirty | lets;
        }
        return $$scope.dirty;
    }
    function update_slot_base(slot, slot_definition, ctx, $$scope, slot_changes, get_slot_context_fn) {
        if (slot_changes) {
            const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);
            slot.p(slot_context, slot_changes);
        }
    }
    function get_all_dirty_from_scope($$scope) {
        if ($$scope.ctx.length > 32) {
            const dirty = [];
            const length = $$scope.ctx.length / 32;
            for (let i = 0; i < length; i++) {
                dirty[i] = -1;
            }
            return dirty;
        }
        return -1;
    }
    function append(target, node) {
        target.appendChild(node);
    }
    function insert(target, node, anchor) {
        target.insertBefore(node, anchor || null);
    }
    function detach(node) {
        if (node.parentNode) {
            node.parentNode.removeChild(node);
        }
    }
    function destroy_each(iterations, detaching) {
        for (let i = 0; i < iterations.length; i += 1) {
            if (iterations[i])
                iterations[i].d(detaching);
        }
    }
    function element(name) {
        return document.createElement(name);
    }
    function text(data) {
        return document.createTextNode(data);
    }
    function space() {
        return text(' ');
    }
    function listen(node, event, handler, options) {
        node.addEventListener(event, handler, options);
        return () => node.removeEventListener(event, handler, options);
    }
    function attr(node, attribute, value) {
        if (value == null)
            node.removeAttribute(attribute);
        else if (node.getAttribute(attribute) !== value)
            node.setAttribute(attribute, value);
    }
    function children(element) {
        return Array.from(element.childNodes);
    }
    function set_data(text, data) {
        data = '' + data;
        if (text.data === data)
            return;
        text.data = data;
    }
    function toggle_class(element, name, toggle) {
        element.classList[toggle ? 'add' : 'remove'](name);
    }
    function custom_event(type, detail, { bubbles = false, cancelable = false } = {}) {
        const e = document.createEvent('CustomEvent');
        e.initCustomEvent(type, bubbles, cancelable, detail);
        return e;
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }
    function get_current_component() {
        if (!current_component)
            throw new Error('Function called outside component initialization');
        return current_component;
    }
    /**
     * The `onMount` function schedules a callback to run as soon as the component has been mounted to the DOM.
     * It must be called during the component's initialisation (but doesn't need to live *inside* the component;
     * it can be called from an external module).
     *
     * `onMount` does not run inside a [server-side component](/docs#run-time-server-side-component-api).
     *
     * https://svelte.dev/docs#run-time-svelte-onmount
     */
    function onMount(fn) {
        get_current_component().$$.on_mount.push(fn);
    }
    /**
     * Creates an event dispatcher that can be used to dispatch [component events](/docs#template-syntax-component-directives-on-eventname).
     * Event dispatchers are functions that can take two arguments: `name` and `detail`.
     *
     * Component events created with `createEventDispatcher` create a
     * [CustomEvent](https://developer.mozilla.org/en-US/docs/Web/API/CustomEvent).
     * These events do not [bubble](https://developer.mozilla.org/en-US/docs/Learn/JavaScript/Building_blocks/Events#Event_bubbling_and_capture).
     * The `detail` argument corresponds to the [CustomEvent.detail](https://developer.mozilla.org/en-US/docs/Web/API/CustomEvent/detail)
     * property and can contain any type of data.
     *
     * https://svelte.dev/docs#run-time-svelte-createeventdispatcher
     */
    function createEventDispatcher() {
        const component = get_current_component();
        return (type, detail, { cancelable = false } = {}) => {
            const callbacks = component.$$.callbacks[type];
            if (callbacks) {
                // TODO are there situations where events could be dispatched
                // in a server (non-DOM) environment?
                const event = custom_event(type, detail, { cancelable });
                callbacks.slice().forEach(fn => {
                    fn.call(component, event);
                });
                return !event.defaultPrevented;
            }
            return true;
        };
    }

    const dirty_components = [];
    const binding_callbacks = [];
    let render_callbacks = [];
    const flush_callbacks = [];
    const resolved_promise = /* @__PURE__ */ Promise.resolve();
    let update_scheduled = false;
    function schedule_update() {
        if (!update_scheduled) {
            update_scheduled = true;
            resolved_promise.then(flush);
        }
    }
    function tick() {
        schedule_update();
        return resolved_promise;
    }
    function add_render_callback(fn) {
        render_callbacks.push(fn);
    }
    // flush() calls callbacks in this order:
    // 1. All beforeUpdate callbacks, in order: parents before children
    // 2. All bind:this callbacks, in reverse order: children before parents.
    // 3. All afterUpdate callbacks, in order: parents before children. EXCEPT
    //    for afterUpdates called during the initial onMount, which are called in
    //    reverse order: children before parents.
    // Since callbacks might update component values, which could trigger another
    // call to flush(), the following steps guard against this:
    // 1. During beforeUpdate, any updated components will be added to the
    //    dirty_components array and will cause a reentrant call to flush(). Because
    //    the flush index is kept outside the function, the reentrant call will pick
    //    up where the earlier call left off and go through all dirty components. The
    //    current_component value is saved and restored so that the reentrant call will
    //    not interfere with the "parent" flush() call.
    // 2. bind:this callbacks cannot trigger new flush() calls.
    // 3. During afterUpdate, any updated components will NOT have their afterUpdate
    //    callback called a second time; the seen_callbacks set, outside the flush()
    //    function, guarantees this behavior.
    const seen_callbacks = new Set();
    let flushidx = 0; // Do *not* move this inside the flush() function
    function flush() {
        // Do not reenter flush while dirty components are updated, as this can
        // result in an infinite loop. Instead, let the inner flush handle it.
        // Reentrancy is ok afterwards for bindings etc.
        if (flushidx !== 0) {
            return;
        }
        const saved_component = current_component;
        do {
            // first, call beforeUpdate functions
            // and update components
            try {
                while (flushidx < dirty_components.length) {
                    const component = dirty_components[flushidx];
                    flushidx++;
                    set_current_component(component);
                    update(component.$$);
                }
            }
            catch (e) {
                // reset dirty state to not end up in a deadlocked state and then rethrow
                dirty_components.length = 0;
                flushidx = 0;
                throw e;
            }
            set_current_component(null);
            dirty_components.length = 0;
            flushidx = 0;
            while (binding_callbacks.length)
                binding_callbacks.pop()();
            // then, once components are updated, call
            // afterUpdate functions. This may cause
            // subsequent updates...
            for (let i = 0; i < render_callbacks.length; i += 1) {
                const callback = render_callbacks[i];
                if (!seen_callbacks.has(callback)) {
                    // ...so guard against infinite loops
                    seen_callbacks.add(callback);
                    callback();
                }
            }
            render_callbacks.length = 0;
        } while (dirty_components.length);
        while (flush_callbacks.length) {
            flush_callbacks.pop()();
        }
        update_scheduled = false;
        seen_callbacks.clear();
        set_current_component(saved_component);
    }
    function update($$) {
        if ($$.fragment !== null) {
            $$.update();
            run_all($$.before_update);
            const dirty = $$.dirty;
            $$.dirty = [-1];
            $$.fragment && $$.fragment.p($$.ctx, dirty);
            $$.after_update.forEach(add_render_callback);
        }
    }
    /**
     * Useful for example to execute remaining `afterUpdate` callbacks before executing `destroy`.
     */
    function flush_render_callbacks(fns) {
        const filtered = [];
        const targets = [];
        render_callbacks.forEach((c) => fns.indexOf(c) === -1 ? filtered.push(c) : targets.push(c));
        targets.forEach((c) => c());
        render_callbacks = filtered;
    }
    const outroing = new Set();
    let outros;
    function group_outros() {
        outros = {
            r: 0,
            c: [],
            p: outros // parent group
        };
    }
    function check_outros() {
        if (!outros.r) {
            run_all(outros.c);
        }
        outros = outros.p;
    }
    function transition_in(block, local) {
        if (block && block.i) {
            outroing.delete(block);
            block.i(local);
        }
    }
    function transition_out(block, local, detach, callback) {
        if (block && block.o) {
            if (outroing.has(block))
                return;
            outroing.add(block);
            outros.c.push(() => {
                outroing.delete(block);
                if (callback) {
                    if (detach)
                        block.d(1);
                    callback();
                }
            });
            block.o(local);
        }
        else if (callback) {
            callback();
        }
    }
    function mount_component(component, target, anchor, customElement) {
        const { fragment, after_update } = component.$$;
        fragment && fragment.m(target, anchor);
        if (!customElement) {
            // onMount happens before the initial afterUpdate
            add_render_callback(() => {
                const new_on_destroy = component.$$.on_mount.map(run).filter(is_function);
                // if the component was destroyed immediately
                // it will update the `$$.on_destroy` reference to `null`.
                // the destructured on_destroy may still reference to the old array
                if (component.$$.on_destroy) {
                    component.$$.on_destroy.push(...new_on_destroy);
                }
                else {
                    // Edge case - component was destroyed immediately,
                    // most likely as a result of a binding initialising
                    run_all(new_on_destroy);
                }
                component.$$.on_mount = [];
            });
        }
        after_update.forEach(add_render_callback);
    }
    function destroy_component(component, detaching) {
        const $$ = component.$$;
        if ($$.fragment !== null) {
            flush_render_callbacks($$.after_update);
            run_all($$.on_destroy);
            $$.fragment && $$.fragment.d(detaching);
            // TODO null out other refs, including component.$$ (but need to
            // preserve final state?)
            $$.on_destroy = $$.fragment = null;
            $$.ctx = [];
        }
    }
    function make_dirty(component, i) {
        if (component.$$.dirty[0] === -1) {
            dirty_components.push(component);
            schedule_update();
            component.$$.dirty.fill(0);
        }
        component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
    }
    function init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {
        const parent_component = current_component;
        set_current_component(component);
        const $$ = component.$$ = {
            fragment: null,
            ctx: [],
            // state
            props,
            update: noop,
            not_equal,
            bound: blank_object(),
            // lifecycle
            on_mount: [],
            on_destroy: [],
            on_disconnect: [],
            before_update: [],
            after_update: [],
            context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),
            // everything else
            callbacks: blank_object(),
            dirty,
            skip_bound: false,
            root: options.target || parent_component.$$.root
        };
        append_styles && append_styles($$.root);
        let ready = false;
        $$.ctx = instance
            ? instance(component, options.props || {}, (i, ret, ...rest) => {
                const value = rest.length ? rest[0] : ret;
                if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                    if (!$$.skip_bound && $$.bound[i])
                        $$.bound[i](value);
                    if (ready)
                        make_dirty(component, i);
                }
                return ret;
            })
            : [];
        $$.update();
        ready = true;
        run_all($$.before_update);
        // `false` as a special case of no DOM component
        $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
        if (options.target) {
            if (options.hydrate) {
                const nodes = children(options.target);
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.l(nodes);
                nodes.forEach(detach);
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.c();
            }
            if (options.intro)
                transition_in(component.$$.fragment);
            mount_component(component, options.target, options.anchor, options.customElement);
            flush();
        }
        set_current_component(parent_component);
    }
    /**
     * Base class for Svelte components. Used when dev=false.
     */
    class SvelteComponent {
        $destroy() {
            destroy_component(this, 1);
            this.$destroy = noop;
        }
        $on(type, callback) {
            if (!is_function(callback)) {
                return noop;
            }
            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
            callbacks.push(callback);
            return () => {
                const index = callbacks.indexOf(callback);
                if (index !== -1)
                    callbacks.splice(index, 1);
            };
        }
        $set($$props) {
            if (this.$$set && !is_empty($$props)) {
                this.$$.skip_bound = true;
                this.$$set($$props);
                this.$$.skip_bound = false;
            }
        }
    }

    /* src/pdf.svelte generated by Svelte v3.59.2 */

    function get_each_context(ctx, list, i) {
    	const child_ctx = ctx.slice();
    	child_ctx[27] = list[i];
    	child_ctx[28] = list;
    	child_ctx[29] = i;
    	return child_ctx;
    }

    // (267:4) {#if numPages}
    function create_if_block(ctx) {
    	let current;
    	const default_slot_template = /*#slots*/ ctx[17].default;
    	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[16], null);
    	const default_slot_or_fallback = default_slot || fallback_block(ctx);

    	return {
    		c() {
    			if (default_slot_or_fallback) default_slot_or_fallback.c();
    		},
    		m(target, anchor) {
    			if (default_slot_or_fallback) {
    				default_slot_or_fallback.m(target, anchor);
    			}

    			current = true;
    		},
    		p(ctx, dirty) {
    			if (default_slot) {
    				if (default_slot.p && (!current || dirty & /*$$scope*/ 65536)) {
    					update_slot_base(
    						default_slot,
    						default_slot_template,
    						ctx,
    						/*$$scope*/ ctx[16],
    						!current
    						? get_all_dirty_from_scope(/*$$scope*/ ctx[16])
    						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[16], dirty, null),
    						null
    					);
    				}
    			} else {
    				if (default_slot_or_fallback && default_slot_or_fallback.p && (!current || dirty & /*classes, pageNumberText, currentPage, numPages*/ 135)) {
    					default_slot_or_fallback.p(ctx, !current ? -1 : dirty);
    				}
    			}
    		},
    		i(local) {
    			if (current) return;
    			transition_in(default_slot_or_fallback, local);
    			current = true;
    		},
    		o(local) {
    			transition_out(default_slot_or_fallback, local);
    			current = false;
    		},
    		d(detaching) {
    			if (default_slot_or_fallback) default_slot_or_fallback.d(detaching);
    		}
    	};
    }

    // (268:14)              
    function fallback_block(ctx) {
    	let div;
    	let button0;
    	let t1;
    	let t2_value = /*pageNumberText*/ ctx[2]?.(/*currentPage*/ ctx[0], /*numPages*/ ctx[7]) + "";
    	let t2;
    	let t3;
    	let button1;
    	let div_class_value;
    	let mounted;
    	let dispose;

    	return {
    		c() {
    			div = element("div");
    			button0 = element("button");
    			button0.textContent = "Previous";
    			t1 = space();
    			t2 = text(t2_value);
    			t3 = space();
    			button1 = element("button");
    			button1.textContent = "Next";
    			attr(div, "class", div_class_value = "controls " + (/*classes*/ ctx[1].controls?.join(" ") ?? "") + " svelte-a811qd");
    		},
    		m(target, anchor) {
    			insert(target, div, anchor);
    			append(div, button0);
    			append(div, t1);
    			append(div, t2);
    			append(div, t3);
    			append(div, button1);

    			if (!mounted) {
    				dispose = [
    					listen(button0, "click", /*navigateLeft*/ ctx[3]),
    					listen(button1, "click", /*navigateRight*/ ctx[4])
    				];

    				mounted = true;
    			}
    		},
    		p(ctx, dirty) {
    			if (dirty & /*pageNumberText, currentPage, numPages*/ 133 && t2_value !== (t2_value = /*pageNumberText*/ ctx[2]?.(/*currentPage*/ ctx[0], /*numPages*/ ctx[7]) + "")) set_data(t2, t2_value);

    			if (dirty & /*classes*/ 2 && div_class_value !== (div_class_value = "controls " + (/*classes*/ ctx[1].controls?.join(" ") ?? "") + " svelte-a811qd")) {
    				attr(div, "class", div_class_value);
    			}
    		},
    		d(detaching) {
    			if (detaching) detach(div);
    			mounted = false;
    			run_all(dispose);
    		}
    	};
    }

    // (277:8) {#each Array.from({length: numPages}) as _, page}
    function create_each_block(ctx) {
    	let canvas;
    	let page = /*page*/ ctx[29];
    	const assign_canvas = () => /*canvas_binding*/ ctx[18](canvas, page);
    	const unassign_canvas = () => /*canvas_binding*/ ctx[18](null, page);

    	return {
    		c() {
    			canvas = element("canvas");
    			attr(canvas, "class", "svelte-a811qd");
    			toggle_class(canvas, "current-page", /*page*/ ctx[29] === /*currentPage*/ ctx[0] - 1);
    		},
    		m(target, anchor) {
    			insert(target, canvas, anchor);
    			assign_canvas();
    		},
    		p(new_ctx, dirty) {
    			ctx = new_ctx;

    			if (page !== /*page*/ ctx[29]) {
    				unassign_canvas();
    				page = /*page*/ ctx[29];
    				assign_canvas();
    			}

    			if (dirty & /*currentPage*/ 1) {
    				toggle_class(canvas, "current-page", /*page*/ ctx[29] === /*currentPage*/ ctx[0] - 1);
    			}
    		},
    		d(detaching) {
    			if (detaching) detach(canvas);
    			unassign_canvas();
    		}
    	};
    }

    function create_fragment(ctx) {
    	let div1;
    	let t;
    	let div0;
    	let div0_class_value;
    	let div1_class_value;
    	let current;
    	let mounted;
    	let dispose;
    	let if_block = /*numPages*/ ctx[7] && create_if_block(ctx);
    	let each_value = Array.from({ length: /*numPages*/ ctx[7] });
    	let each_blocks = [];

    	for (let i = 0; i < each_value.length; i += 1) {
    		each_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));
    	}

    	return {
    		c() {
    			div1 = element("div");
    			if (if_block) if_block.c();
    			t = space();
    			div0 = element("div");

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				each_blocks[i].c();
    			}

    			attr(div0, "class", div0_class_value = "viewer " + (/*classes*/ ctx[1].container?.join(" ") ?? "") + " svelte-a811qd");
    			attr(div1, "class", div1_class_value = "pdf-svelte theme-" + /*opts*/ ctx[5].theme + " display-" + /*opts*/ ctx[5].display + " fit-" + /*opts*/ ctx[5].fit + " " + (/*classes*/ ctx[1].overall?.join(" ") ?? "") + " svelte-a811qd");
    		},
    		m(target, anchor) {
    			insert(target, div1, anchor);
    			if (if_block) if_block.m(div1, null);
    			append(div1, t);
    			append(div1, div0);

    			for (let i = 0; i < each_blocks.length; i += 1) {
    				if (each_blocks[i]) {
    					each_blocks[i].m(div0, null);
    				}
    			}

    			/*div0_binding*/ ctx[19](div0);
    			current = true;

    			if (!mounted) {
    				dispose = listen(div0, "dblclick", /*autoZoom*/ ctx[9]);
    				mounted = true;
    			}
    		},
    		p(ctx, [dirty]) {
    			if (/*numPages*/ ctx[7]) {
    				if (if_block) {
    					if_block.p(ctx, dirty);

    					if (dirty & /*numPages*/ 128) {
    						transition_in(if_block, 1);
    					}
    				} else {
    					if_block = create_if_block(ctx);
    					if_block.c();
    					transition_in(if_block, 1);
    					if_block.m(div1, t);
    				}
    			} else if (if_block) {
    				group_outros();

    				transition_out(if_block, 1, 1, () => {
    					if_block = null;
    				});

    				check_outros();
    			}

    			if (dirty & /*pages, currentPage, numPages*/ 385) {
    				each_value = Array.from({ length: /*numPages*/ ctx[7] });
    				let i;

    				for (i = 0; i < each_value.length; i += 1) {
    					const child_ctx = get_each_context(ctx, each_value, i);

    					if (each_blocks[i]) {
    						each_blocks[i].p(child_ctx, dirty);
    					} else {
    						each_blocks[i] = create_each_block(child_ctx);
    						each_blocks[i].c();
    						each_blocks[i].m(div0, null);
    					}
    				}

    				for (; i < each_blocks.length; i += 1) {
    					each_blocks[i].d(1);
    				}

    				each_blocks.length = each_value.length;
    			}

    			if (!current || dirty & /*classes*/ 2 && div0_class_value !== (div0_class_value = "viewer " + (/*classes*/ ctx[1].container?.join(" ") ?? "") + " svelte-a811qd")) {
    				attr(div0, "class", div0_class_value);
    			}

    			if (!current || dirty & /*opts, classes*/ 34 && div1_class_value !== (div1_class_value = "pdf-svelte theme-" + /*opts*/ ctx[5].theme + " display-" + /*opts*/ ctx[5].display + " fit-" + /*opts*/ ctx[5].fit + " " + (/*classes*/ ctx[1].overall?.join(" ") ?? "") + " svelte-a811qd")) {
    				attr(div1, "class", div1_class_value);
    			}
    		},
    		i(local) {
    			if (current) return;
    			transition_in(if_block);
    			current = true;
    		},
    		o(local) {
    			transition_out(if_block);
    			current = false;
    		},
    		d(detaching) {
    			if (detaching) detach(div1);
    			if (if_block) if_block.d();
    			destroy_each(each_blocks, detaching);
    			/*div0_binding*/ ctx[19](null);
    			mounted = false;
    			dispose();
    		}
    	};
    }

    const autoZoomMin = 1, autoZoomMax = 1.5;

    /**
     * @function
     * @template {function(...*): void} TFunc
     * @param {TFunc} func
     * @param {number} timeout
     * @returns {TFunc}
     * @this {*}
    */
    function debounce(func, timeout = 500) {
    	/** @type {undefined | ReturnType<setTimeout>} */
    	let timer;

    	// @ts-ignore
    	return (...args) => {
    		if (!timer) {
    			// First call is leading edge (call immediately)
    			timer = setTimeout(() => timer = undefined, timeout);

    			func(...args);
    		} else {
    			// Subsequent calls are trailing edge (wait until they stop)
    			clearTimeout(timer);

    			timer = setTimeout(
    				() => {
    					func(...args);
    					timer = undefined;
    				},
    				timeout
    			);
    		}
    	};
    }

    function instance($$self, $$props, $$invalidate) {
    	let { $$slots: slots = {}, $$scope } = $$props;
    	const dispatch = createEventDispatcher();

    	/** @type {import("pdfjs-dist")} */
    	let pdfjs;

    	onMount(async () => {
    		pdfjs = await import('pdfjs-dist');

    		// @ts-ignore
    		await Promise.resolve().then(function () { return pdf_worker_entry; });
    	});

    	/** @typedef {{
     *     display: "paged" | "all",
     *     theme: "none" | "light" | "dark" | string,
     *     autoZoomEnabled: boolean,
     *     upscale: number,
     *     fit: "horizontal" | "vertical" | "both"
     * }} Options */
    	/** @typedef {string | URL | ArrayBuffer 
     *     | import("pdfjs-dist/types/src/display/api").TypedArray
     *     | import("pdfjs-dist/types/src/display/api").DocumentInitParameters
     * } PDFSource */
    	/** @type {Options} */
    	const defaultOptions = {
    		// paged, all
    		display: "paged",
    		// dark, light, none
    		theme: 'dark',
    		autoZoomEnabled: false,
    		upscale: 8,
    		// horizontal, vertical, both
    		fit: "both"
    	};

    	let { pdf } = $$props;
    	let { classes = {} } = $$props;
    	let { options = defaultOptions } = $$props;
    	let { zoom = 1 } = $$props;
    	let { currentPage = 1 } = $$props;
    	let { pageNumberText = (currentPage, totalPages) => `${currentPage}/${totalPages}` } = $$props;

    	/** @type {Options} */
    	let opts;

    	/** @type {HTMLDivElement} */
    	let pageContainer;

    	/** @type {import("pdfjs-dist").PDFDocumentProxy} */
    	let doc;

    	/** @type {number} */
    	let numPages = 0;

    	/** @type {HTMLCanvasElement[]} */
    	let pages = [];

    	/** @type {number} */
    	let oldZoom = 0;

    	/** @function
     * @param {PDFSource} src
     * returns {void}
    */
    	const render = debounce(/** @function @param {PDFSource} src */
    	async src => {
    		if (!src) return;

    		if (!pdfjs) {
    			// using debounce behaviour to not infinitely loop
    			render(src);

    			return;
    		}

    		doc = await pdfjs.getDocument(src).promise;
    		$$invalidate(7, numPages = doc.numPages);
    		await tick();

    		// Load every page 
    		await Promise.all(pages.map(async (canvas, pageNum) => {
    			const page = await doc.getPage(pageNum + 1);
    			let viewport = page.getViewport({ scale: 1 });
    			const boundingRect = pageContainer.getBoundingClientRect();
    			const pageScale = Math.min(boundingRect.width / viewport.width, boundingRect.height / viewport.height);
    			viewport = viewport.clone({ scale: pageScale * opts.upscale / zoom });
    			canvas.height = viewport.height;
    			canvas.width = viewport.width;
    			canvas.style.aspectRatio = `${viewport.width} / ${viewport.height}`;

    			const context = /** @type {CanvasRenderingContext2D} */
    			canvas.getContext('2d');

    			page.render({ canvasContext: context, viewport });
    		}));

    		$$invalidate(15, oldZoom = zoom);
    		dispatch("ready");
    	});

    	const navigateLeft = () => {
    		$$invalidate(0, currentPage = Math.max(currentPage - 1, 1));
    	};

    	const navigateRight = () => {
    		$$invalidate(0, currentPage = Math.min(currentPage + 1, numPages));
    	};

    	// Zoom
    	const zoomLevels = [0.1, 0.25, 0.5, 0.66, 0.8, 0.9, 1, 1.2, 1.5, 2, 3, 4, 5];

    	/**
     * @function
     * @param {-1 | 1 | number} offset - the number of predefined zoom steps to move
    */
    	function adjustZoom(offset) {
    		const currentIndex = (() => {
    			let i = 0;

    			while (i < zoomLevels.length && zoomLevels[i] < zoom) {
    				i++;
    			}

    			if (zoom != zoomLevels[i] && offset > 0) --i;
    			return i;
    		})();

    		const newLevel = Math.min(Math.max(currentIndex + offset, 0), zoomLevels.length - 1);
    		$$invalidate(10, zoom = zoomLevels[newLevel]);
    	}

    	function zoomIn() {
    		adjustZoom(1);
    	}

    	function zoomOut() {
    		adjustZoom(-1);
    	}

    	function autoZoom() {
    		if (opts.autoZoomEnabled) {
    			$$invalidate(10, zoom = zoom < autoZoomMin || zoom >= autoZoomMax
    			? autoZoomMin
    			: autoZoomMax);
    		}
    	}

    	function canvas_binding($$value, page) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			pages[page] = $$value;
    			$$invalidate(8, pages);
    		});
    	}

    	function div0_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			pageContainer = $$value;
    			$$invalidate(6, pageContainer);
    		});
    	}

    	$$self.$$set = $$props => {
    		if ('pdf' in $$props) $$invalidate(11, pdf = $$props.pdf);
    		if ('classes' in $$props) $$invalidate(1, classes = $$props.classes);
    		if ('options' in $$props) $$invalidate(12, options = $$props.options);
    		if ('zoom' in $$props) $$invalidate(10, zoom = $$props.zoom);
    		if ('currentPage' in $$props) $$invalidate(0, currentPage = $$props.currentPage);
    		if ('pageNumberText' in $$props) $$invalidate(2, pageNumberText = $$props.pageNumberText);
    		if ('$$scope' in $$props) $$invalidate(16, $$scope = $$props.$$scope);
    	};

    	$$self.$$.update = () => {
    		if ($$self.$$.dirty & /*options*/ 4096) {
    			$$invalidate(5, opts = { ...defaultOptions, ...options });
    		}

    		if ($$self.$$.dirty & /*zoom*/ 1024) {
    			if (zoom <= 0) $$invalidate(10, zoom = 1);
    		}

    		if ($$self.$$.dirty & /*pdf*/ 2048) {
    			render(pdf);
    		}

    		if ($$self.$$.dirty & /*zoom, oldZoom, pdf*/ 35840) {
    			if (zoom && oldZoom && zoom != oldZoom) {
    				render(pdf);
    				$$invalidate(15, oldZoom = zoom);
    			}
    		}
    	};

    	return [
    		currentPage,
    		classes,
    		pageNumberText,
    		navigateLeft,
    		navigateRight,
    		opts,
    		pageContainer,
    		numPages,
    		pages,
    		autoZoom,
    		zoom,
    		pdf,
    		options,
    		zoomIn,
    		zoomOut,
    		oldZoom,
    		$$scope,
    		slots,
    		canvas_binding,
    		div0_binding
    	];
    }

    class Pdf extends SvelteComponent {
    	constructor(options) {
    		super();

    		init(this, options, instance, create_fragment, safe_not_equal, {
    			pdf: 11,
    			classes: 1,
    			options: 12,
    			zoom: 10,
    			currentPage: 0,
    			pageNumberText: 2,
    			navigateLeft: 3,
    			navigateRight: 4,
    			zoomIn: 13,
    			zoomOut: 14
    		});
    	}

    	get navigateLeft() {
    		return this.$$.ctx[3];
    	}

    	get navigateRight() {
    		return this.$$.ctx[4];
    	}

    	get zoomIn() {
    		return this.$$.ctx[13];
    	}

    	get zoomOut() {
    		return this.$$.ctx[14];
    	}
    }

    /* Copyright 2022 Mozilla Foundation
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *     http://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */

    (typeof window !== "undefined"
      ? window
      : {}
    ).pdfjsWorker = require("./pdf.worker.js");

    var pdf_worker_entry = /*#__PURE__*/Object.freeze({
        __proto__: null
    });

    return Pdf;

})));
